@@ -1,7 +1,6 @@
 import datetime
 import json
 import os
-import six
 from .utils import (
     suck_out_editions,
     names_to_abbreviations,
@@ -11,14 +10,10 @@ from .utils import (
 )
 
 
-# noinspection PyBroadException
 def datetime_parser(dct):
     for k, v in dct.items():
-        if isinstance(v, six.string_types):
-            try:
-                dct[k] = datetime.datetime.strptime(v, "%Y-%m-%dT%H:%M:%S")
-            except:
-                pass
+        if k in ("start", "end") and v is not None:
+            dct[k] = datetime.datetime.strptime(v, "%Y-%m-%dT%H:%M:%S")
     return dct
 
 
@@ -35,6 +30,14 @@ with open(os.path.join(db_root, "data", "case_name_abbreviations.json")) as f:
     CASE_NAME_ABBREVIATIONS = json.load(f)
 
 
+with open(os.path.join(db_root, "data", "laws.json")) as f:
+    LAWS = json.load(f, object_hook=datetime_parser)
+
+
+with open(os.path.join(db_root, "data", "journals.json")) as f:
+    JOURNALS = json.load(f, object_hook=datetime_parser)
+
+
 with open(os.path.join(db_root, "data", "regexes.json")) as f:
     RAW_REGEX_VARIABLES = json.load(f)
     REGEX_VARIABLES = process_variables(RAW_REGEX_VARIABLES)
